@@ -11,19 +11,17 @@ def run():
     import sys
     import logging
 
-    print(sys.executable)
-
-    log_file = 'dummy_autoupdate_log.txt'
-    logging.basicConfig(level=logging.DEBUG, filename=log_file)
-    print((Path(__file__).parent / log_file).resolve())
+    logging.basicConfig(level=logging.DEBUG)
 
     qapp = QApplication([])
+    logger = logging.getLogger(__name__)
     window = MainWindow(__version__)
     reboot_exit = window.EXIT_CODE_REBOOT
     exit_code = qapp.exec_()
 
     if exit_code == reboot_exit:
         python = sys.executable
+        logger.info(f'Rebooting the program with {python}...')
         os.execl(python, python, *sys.argv)
 
 
